@@ -72,7 +72,7 @@ std::string changes_manage (Webserver_Request& webserver_request)
     const int jobId = database_jobs.get_new_id ();
     database_jobs.set_level (jobId, Filter_Roles::manager ());
     database_jobs.set_start (jobId, translate ("Clearing change notifications."));
-    tasks_logic_queue (DELETECHANGES, {std::to_string (jobId), username});
+    tasks_logic_queue (task::delete_changes, {std::to_string (jobId), username});
     redirect_browser (webserver_request, jobs_index_url () + "?id=" + std::to_string (jobId));
     return std::string();
   }
