@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -38,6 +38,4 @@ public:
   std::vector <std::string> names ();
   std::string original ();
   std::vector <Passage> translate (const std::string& input, const std::string& output, int book, int chapter, int verse);
-private:
-  sqlite3 * connect ();
 };
