@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ public:
   int m_chapter {};
   std::string m_verse {};
   bool equal (Passage & passage);
-  std::string encode ();
+  std::string encode () const;
   static Passage decode (const std::string& encoded);
 };
 
