@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,14 +28,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <tlhelp32.h>
 #endif
 #include <developer/logic.h>
-using namespace std;
 
 
-// Internal declarations.
-string filter_shell_escape_argument (string argument);
-
-
-string filter_shell_escape_argument (string argument)
+static std::string filter_shell_escape_argument (std::string argument)
 {
   argument = filter::strings::replace ("'", "\\'", argument);
   argument.insert (0, "'");
@@ -47,11 +42,11 @@ string filter_shell_escape_argument (string argument)
 // Runs shell $command in folder $directory, with $parameters.
 // If $output and $error are non-nullptr, that is where the output of the shell command goes.
 // If they are nullptr, the output of the shell command goes to the Journal.
-int filter_shell_run ([[maybe_unused]] string directory,
-                      string command,
-                      [[maybe_unused]] const vector <string> parameters,
-                      [[maybe_unused]] string * output,
-                      [[maybe_unused]] string * error)
+int filter_shell_run ([[maybe_unused]] std::string directory,
+                      std::string command,
+                      [[maybe_unused]] const std::vector <std::string> parameters,
+                      [[maybe_unused]] std::string * output,
+                      [[maybe_unused]] std::string * error)
 {
 #ifdef HAVE_CLIENT
   Database_Logs::log ("Did not run on client: " + command);
@@ -62,17 +57,17 @@ int filter_shell_run ([[maybe_unused]] string directory,
     directory = filter_shell_escape_argument (directory);
     command.insert (0, "cd " + directory + "; ");
   }
-  for (string parameter : parameters) {
+  for (std::string parameter : parameters) {
     parameter = filter_shell_escape_argument (parameter);
     command.append (" " + parameter);
   }
-  string pipe = filter_url_tempfile ();
-  string standardout = pipe + ".out";
-  string standarderr = pipe + ".err";
+  std::string pipe = filter_url_tempfile ();
+  std::string standardout = pipe + ".out";
+  std::string standarderr = pipe + ".err";
   command.append (" > " + standardout);
   command.append (" 2> " + standarderr);
   int result = system (command.c_str());
-  string contents = filter_url_file_get_contents (standardout);
+  std::string contents = filter_url_file_get_contents (standardout);
   if (output) {
     output->assign (contents);
   } else {
@@ -93,16 +88,16 @@ int filter_shell_run ([[maybe_unused]] string directory,
 
 // Runs $command with $parameters.
 // It does not run $command through the shell, but executes it straight.
-int filter_shell_run (string command,
+int filter_shell_run (std::string command,
                       [[maybe_unused]] const char * parameter,
-                      [[maybe_unused]] string & output)
+                      [[maybe_unused]] std::string & output)
 {
 #ifdef HAVE_CLIENT
   Database_Logs::log ("Did not run on client: " + command);
   return 0;
 #else
   // File descriptor for file to write child's stdout to.
-  string path = filter_url_tempfile () + ".txt";
+  std::string path = filter_url_tempfile () + ".txt";
   int fd = open (path.c_str (), O_WRONLY|O_CREAT, 0666);
   
   // Create child process as a duplicate of this process.
@@ -113,7 +108,7 @@ int filter_shell_run (string command,
     // This runs in the child.
     dup2(fd, 1);
     close(fd);
-    execlp (command.c_str(), parameter, static_cast<char*> (0));
+    execlp (command.c_str(), parameter, nullptr);
     // The above only returns in case of an error.
     Database_Logs::log (strerror (errno));
     // Use_exit instead of exit, so there's no flushing.
@@ -138,12 +133,12 @@ int filter_shell_run (string command,
 // Does not escape anything in the $command.
 // Returns the exit code of the process.
 // The output of the process, both stdout and stderr, go into $out_err.
-int filter_shell_run (string command, string & out_err)
+int filter_shell_run (std::string command, std::string & out_err)
 {
 #ifdef HAVE_IOS
   return 0;
 #else
-  string pipe = filter_url_tempfile ();
+  std::string pipe = filter_url_tempfile ();
   command.append (" > " + pipe + " 2>&1");
   int result = system (command.c_str());
   out_err = filter_url_file_get_contents (pipe);
@@ -153,13 +148,13 @@ int filter_shell_run (string command, string & out_err)
 
 
 // Returns true if $program is present on the system.
-bool filter_shell_is_present (string program)
+bool filter_shell_is_present (std::string program)
 {
   // This crashes on iOS, so skip it.
 #ifdef HAVE_IOS
   return false;
 #else
-  string command = "which " + program + " > /dev/null 2>&1";
+  std::string command = "which " + program + " > /dev/null 2>&1";
   int exitcode = system (command.c_str ());
   return (exitcode == 0);
 #endif
@@ -167,9 +162,9 @@ bool filter_shell_is_present (string program)
 
 
 // Lists the running processes.
-vector <string> filter_shell_active_processes ()
+std::vector <std::string> filter_shell_active_processes ()
 {
-  vector <string> processes;
+  std::vector <std::string> processes;
 
 #ifdef HAVE_WINDOWS
 
@@ -188,7 +183,7 @@ vector <string> filter_shell_active_processes ()
 
 #else
 
-  string output;
+  std::string output;
   filter_shell_run ("ps ax", output);
   processes = filter::strings::explode (output, '\n');
 
@@ -202,9 +197,9 @@ vector <string> filter_shell_active_processes ()
 // If $directory is given, the process changes the working directory to that.
 // It does not run $command through the shell, but executes it through vfork,
 // which is the fastest possibble way to run a child process.
-int filter_shell_vfork ([[maybe_unused]] string & output,
-                        [[maybe_unused]] string directory,
-                        [[maybe_unused]] string command,
+int filter_shell_vfork ([[maybe_unused]] std::string & output,
+                        [[maybe_unused]] std::string directory,
+                        [[maybe_unused]] std::string command,
                         [[maybe_unused]] const char * p01,
                         [[maybe_unused]] const char * p02,
                         [[maybe_unused]] const char * p03,
@@ -225,12 +220,12 @@ int filter_shell_vfork ([[maybe_unused]] string & output,
 #else
 
   // File descriptors for files to write child's stdout and stderr to.
-  string path = filter_url_tempfile () + ".txt";
+  std::string path = filter_url_tempfile () + ".txt";
   int fd = open (path.c_str (), O_WRONLY|O_CREAT, 0666);
 
   // It seems that waiting very shortly before calling vfork ()
   // enables running threads to continue running.
-  this_thread::sleep_for (chrono::milliseconds (1));
+  std::this_thread::sleep_for (std::chrono::milliseconds (1));
 #pragma clang diagnostic push
 #pragma clang diagnostic ignored "-Wdeprecated-declarations"
   pid_t pid = vfork();
@@ -250,7 +245,7 @@ int filter_shell_vfork ([[maybe_unused]] string & output,
     if (!directory.empty ()) {
       [[maybe_unused]] int result = chdir (directory.c_str());
     }
-    execlp (command.c_str(), command.c_str(), p01, p02, p03, p04, p05, p06, p07, p08, p09, p10, p11, p12, p13, static_cast<char*> (0));
+    execlp (command.c_str(), command.c_str(), p01, p02, p03, p04, p05, p06, p07, p08, p09, p10, p11, p12, p13, nullptr);
     // The above only returns in case of an error.
     Database_Logs::log (command + ": " + strerror (errno));
     _exit (1);
