@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -48,6 +48,6 @@ bool in_array (const T & needle, const std::vector <T> & haystack)
 // Clip a value to not be less than "lower" and not more than "higher"
 template <typename T>
 T clip (const T& n, const T& lower, const T& upper) {
-  return std::max (lower, std::min (n, upper));
+  return std::max<T> (lower, std::min<T> (n, upper));
 }
 
