@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,14 +17,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_FILTER_WEBVIEW_H
-#define INCLUDED_FILTER_WEBVIEW_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-void filter_webview_log_user_agent (string user_agent);
-
-
-#endif
+void filter_webview_log_user_agent (std::string user_agent);
