@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,13 +30,10 @@
 #include <webserver/request.h>
 
 
-void manage_hyphenate (string bible, string user)
+void manage_hyphenate (std::string bible, std::string user)
 {
-  Database_Bibles database_bibles;
-
-
-  string inputBible (bible);
-  string outputBible = inputBible + "-hyphenated";
+  std::string inputBible (bible);
+  std::string outputBible = inputBible + "-hyphenated";
   
   
   Database_Logs::log ("Reading Bible " + inputBible + ", adding soft hyphens, putting it into Bible " + outputBible);
@@ -44,47 +41,47 @@ void manage_hyphenate (string bible, string user)
   
   // Get the two sets of characters as arrays.
   // The /u switch treats the text as UTF8 Unicode.
-  vector <string> firstset;
-  string s_firstset = Database_Config_Bible::getHyphenationFirstSet (inputBible);
-  size_t length = unicode_string_length (s_firstset);
+  std::vector <std::string> firstset;
+  std::string s_firstset = database::config::bible::get_hyphenation_first_set (inputBible);
+  size_t length = filter::strings::unicode_string_length (s_firstset);
   for (size_t i = 0; i < length; i++) {
-    string s = unicode_string_substr (s_firstset, i, 1);
+    std::string s = filter::strings::unicode_string_substr (s_firstset, i, 1);
     if (s == " ") continue;
     firstset.push_back (s);
   }
-  vector <string> secondset;
-  string s_secondset = Database_Config_Bible::getHyphenationSecondSet (inputBible);
-  length = unicode_string_length (s_secondset);
+  std::vector <std::string> secondset;
+  std::string s_secondset = database::config::bible::get_hyphenation_second_set (inputBible);
+  length = filter::strings::unicode_string_length (s_secondset);
   for (size_t i = 0; i < length; i++) {
-    string s = unicode_string_substr (s_secondset, i, 1);
+    std::string s = filter::strings::unicode_string_substr (s_secondset, i, 1);
     if (s == " ") continue;
     secondset.push_back (s);
   }
  
   
   // Delete and (re)create the hyphenated Bible.
-  database_bibles.deleteBible (outputBible);
-  Database_Privileges::removeBible (outputBible);
-  Database_Config_Bible::remove (outputBible);
-  database_bibles.createBible (outputBible);
+  database::bibles::delete_bible (outputBible);
+  DatabasePrivileges::remove_bible (outputBible);
+  database::config::bible::remove (outputBible);
+  database::bibles::create_bible (outputBible);
   Webserver_Request webserver_request;
-  if (!AccessBible::Write (&webserver_request, outputBible, user)) {
+  if (!access_bible::write (webserver_request, outputBible, user)) {
     // Only grant access if the user does not yet have it.
     // This avoid assigning the Bible to the user in case no Bible was assigned to anyone,
     // in which case assigning this Bible to the user would possible withdraw privileges from other users.
-    Database_Privileges::setBible (user, outputBible, true);
+    DatabasePrivileges::set_bible (user, outputBible, true);
   }
   
   
   // Go through the input Bible's books and chapters.
-  vector <int> books = database_bibles.getBooks (inputBible);
+  std::vector <int> books = database::bibles::get_books (inputBible);
   for (auto book : books) {
-    Database_Logs::log (Database_Books::getEnglishFromId (book));
-    vector <int> chapters = database_bibles.getChapters (inputBible, book);
+    Database_Logs::log (database::books::get_english_from_id (static_cast<book_id>(book)));
+    std::vector <int> chapters = database::bibles::get_chapters (inputBible, book);
     for (auto chapter : chapters) {
-      string data = database_bibles.getChapter (inputBible, book, chapter);
+      std::string data = database::bibles::get_chapter (inputBible, book, chapter);
       data = hyphenate_at_transition (firstset, secondset, data);
-      database_bibles.storeChapter (outputBible, book, chapter, data);
+      database::bibles::store_chapter (outputBible, book, chapter, data);
     }
   }
 
@@ -103,7 +100,7 @@ void manage_hyphenate (string bible, string user)
  * $text: A string of text to operate on.
  * Returns: The hyphenated text.
  */
-string hyphenate_at_transition (vector <string>& firstset, vector <string>& secondset, string text)
+std::string hyphenate_at_transition (std::vector <std::string>& firstset, std::vector <std::string>& secondset, std::string text)
 {
   // Verify the input.
   if (firstset.empty ()) return text;
@@ -111,14 +108,14 @@ string hyphenate_at_transition (vector <string>& firstset, vector <string>& seco
   if (text.empty ()) return text;
   
   // Split the text up into lines and go through each one.
-  vector <string> lines = filter_string_explode (text, '\n');
-  for (string & line : lines) {
+  std::vector <std::string> lines = filter::strings::explode (text, '\n');
+  for (std::string & line : lines) {
     
     // Split the line up into an array of UTF8 Unicode characters.
-    vector <string> characters;
-    size_t length = unicode_string_length (line);
+    std::vector <std::string> characters;
+    size_t length = filter::strings::unicode_string_length (line);
     for (size_t i = 0; i < length; i++) {
-      string s = unicode_string_substr (line, i, 1);
+      std::string s = filter::strings::unicode_string_substr (line, i, 1);
       characters.push_back (s);
     }
     
@@ -130,7 +127,7 @@ string hyphenate_at_transition (vector <string>& firstset, vector <string>& seco
     // Process each character.
     for (unsigned int i = 0; i < characters.size (); i++) {
       
-      string character = characters [i];
+      std::string character = characters [i];
       
       // Skip USFM marker.
       if (character == "\\") isUsfm = true;
@@ -141,7 +138,7 @@ string hyphenate_at_transition (vector <string>& firstset, vector <string>& seco
         thisCharacterIsRelevant = in_array (character, secondset);
         if ((thisCharacterIsRelevant) && (previousCharacterWasRelevant)) {
           if (!hyphenate_is_near_white_space (characters, static_cast<int> (i))) {
-            characters[i] = soft_hyphen_u00AD () + character;
+            characters[i] = filter::strings::soft_hyphen_u00AD () + character;
           }
         }
         
@@ -157,12 +154,12 @@ string hyphenate_at_transition (vector <string>& firstset, vector <string>& seco
     }
     
     // Re-assemble the line from the separate (updated) characters.
-    line = filter_string_implode (characters, "");
+    line = filter::strings::implode (characters, "");
     
   }
   
   // Assemble the hyphenated text from the separate lines.
-  text = filter_string_implode (lines, "\n");
+  text = filter::strings::implode (lines, "\n");
   return text;
 }
 
@@ -172,15 +169,15 @@ string hyphenate_at_transition (vector <string>& firstset, vector <string>& seco
  * in the vector of characters.
  * Returns: true or false.
  */
-bool hyphenate_is_near_white_space (const vector <string> & characters, int offset)
+bool hyphenate_is_near_white_space (const std::vector <std::string> & characters, int offset)
 {
   // The constant for the nearness to the start of the word.
-  size_t start = static_cast<size_t> (offset - 2);
+  int start = offset - 2;
   // The constant for the nearness to the end of the word.
-  size_t end = static_cast<size_t>(offset + 2);
+  int end = offset + 2;
   if (start < 0) start = 0;
-  if (end > characters.size()) end = characters.size();
-  for (size_t i = start; i < end; i++) {
+  if (end > static_cast<int>(characters.size())) end = static_cast<int> (characters.size());
+  for (size_t i = static_cast<size_t>(start); i < static_cast<size_t>(end); i++) {
     if (characters[i] == " ") return true;
   }
   return false;
