@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,14 +17,8 @@
  */
 
 
-#ifndef INCLUDED_PUGIXML_UTILS_H
-#define INCLUDED_PUGIXML_UTILS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-void pugixml_utils_error_logger (void * pugi_xml_parse_result, const string & xml);
-
-
-#endif
+void pugixml_utils_error_logger (void * pugi_xml_parse_result, const std::string & xml);
