@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
-string resource_comparative9edit_url ();
-bool resource_comparative9edit_acl (void * webserver_request);
-string resource_comparative9edit (void * webserver_request);
+class Webserver_Request;
+
+std::string resource_comparative9edit_url ();
+bool resource_comparative9edit_acl (Webserver_Request& webserver_request);
+std::string resource_comparative9edit (Webserver_Request& webserver_request);
