@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,43 +34,41 @@
 #include <access/bible.h>
 
 
-string search_strongs_url ()
+std::string search_strongs_url ()
 {
   return "search/strongs";
 }
 
 
-bool search_strongs_acl (void * webserver_request)
+bool search_strongs_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ()))
+    return true;
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string search_strongs (void * webserver_request)
+std::string search_strongs (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-
   Database_Kjv database_kjv = Database_Kjv ();
   
 
-  string bible = request->database_config_user()->getBible ();
-  if (request->query.count ("b")) {
-    bible = request->query ["b"];
+  std::string bible = webserver_request.database_config_user()->getBible ();
+  if (webserver_request.query.count ("b")) {
+    bible = webserver_request.query ["b"];
   }
   
   
-  if (request->query.count ("load")) {
+  if (webserver_request.query.count ("load")) {
     
-    int book = Ipc_Focus::getBook (request);
-    int chapter = Ipc_Focus::getChapter (request);
-    int verse = Ipc_Focus::getVerse (request);
+    const int book = Ipc_Focus::getBook (webserver_request);
+    const int chapter = Ipc_Focus::getChapter (webserver_request);
+    const int verse = Ipc_Focus::getVerse (webserver_request);
     
     // Get Strong's numbers, plus English snippets.
-    string searchtext;
-    vector <Database_Kjv_Item> details = database_kjv.getVerse (book, chapter, verse);
+    std::string searchtext {};
+    std::vector <Database_Kjv_Item> details = database_kjv.getVerse (book, chapter, verse);
     for (unsigned int i = 0; i < details.size(); i++) {
       if (i) searchtext += " ";
       searchtext += details[i].strong;
@@ -79,39 +77,39 @@ string search_strongs (void * webserver_request)
       searchtext += ")";
     }
     
-    searchtext = filter_string_trim (searchtext);
+    searchtext = filter::strings::trim (searchtext);
     
     return searchtext;
   }
   
   
-  if (request->query.count ("words")) {
+  if (webserver_request.query.count ("words")) {
     
-    string s_words = request->query ["words"];
-    s_words = filter_string_trim (s_words);
-    vector <string> words = filter_string_explode (s_words, ' ');
+    std::string s_words {webserver_request.query ["words"]};
+    s_words = filter::strings::trim (s_words);
+    const std::vector <std::string> words {filter::strings::explode (s_words, ' ')};
     
     // Include items if there are no more search hits than 30% of the total number of verses in the KJV.
-    size_t maxcount = static_cast<size_t> (round (0.3 * 31102));
+    const size_t maxcount = static_cast<size_t> (round (0.3 * 31102));
     
     // Store how often a verse occurs in an array.
     // The keys are the passages of the search results.
     // The values are how often the passages occur in the search results.
-    map <int, int> passages;
+    std::map <int, int> passages {};
     
-    for (auto & strong : words) {
+    for (const auto& strong : words) {
       
       // Skip short words.
       if (strong.length () < 2) continue;
       
       // Find out how often this word occurs in the Bible. Skip if too often.
-      vector <Passage> details = database_kjv.searchStrong (strong);
+      const std::vector <Passage> details {database_kjv.searchStrong (strong)};
       if (details.size() < 1) continue;
       if (details.size () > maxcount) continue;
       
       // Store the identifiers and their count.
-      for (auto & passage : details) {
-        int i_passage = filter_passage_to_integer (passage);
+      for (const auto& passage : details) {
+        const int i_passage = filter_passage_to_integer (passage);
         if (passages.count (i_passage)) passages [i_passage]++;
         else passages [i_passage] = 1;
       }
@@ -120,66 +118,67 @@ string search_strongs (void * webserver_request)
     
     // Sort on occurrence from high to low.
     // Skip identifiers that only occur once.
-    vector <int> i_passages;
-    vector <int> counts;
-    for (auto & element : passages) {
+    std::vector <int> i_passages {};
+    std::vector <int> counts {};
+    for (const auto& element : passages) {
       int i_passage = element.first;
-      int count = element.second;
+      const int count = element.second;
       if (count <= 1) continue;
       i_passages.push_back (i_passage);
       counts.push_back (count);
     }
-    quick_sort (counts, i_passages, 0, static_cast<unsigned int>(counts.size()));
+    filter::strings::quick_sort (counts, i_passages, 0, static_cast<unsigned int>(counts.size()));
     reverse (i_passages.begin(), i_passages.end());
 
     // Output the passage identifiers to the browser.
-    string output;
+    std::string output {};
     for (auto & i_passage : i_passages) {
       if (!output.empty ()) output.append ("\n");
-      output.append (convert_to_string (i_passage));
+      output.append (std::to_string (i_passage));
     }
     return output;
   }
   
   
-  if (request->query.count ("id")) {
-    int id = convert_to_int (request->query ["id"]);
+  if (webserver_request.query.count ("id")) {
+    const int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
     
     // Get the and passage for this identifier.
-    Passage passage = filter_integer_to_passage (id);
-    int book = passage.book;
-    int chapter = passage.chapter;
-    string verse = passage.verse;
+    const Passage passage = filter_integer_to_passage (id);
+    const int book = passage.m_book;
+    const int chapter = passage.m_chapter;
+    const std::string verse = passage.m_verse;
     
     // Get the plain text.
-    string text = search_logic_get_bible_verse_text (bible, book, chapter, convert_to_int (verse));
+    const std::string text = search_logic_get_bible_verse_text (bible, book, chapter, filter::strings::convert_to_int (verse));
     
     // Format it.
-    string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
-    string output = "<div>" + link + " " + text + "</div>";
+    const std::string link = filter_passage_link_for_opening_editor_at (book, chapter, verse);
+    const std::string output = "<div>" + link + " " + text + "</div>";
     
     // Output to browser.
     return output;
   }
   
   
-  string page;
+  std::string page {};
   
-  Assets_Header header = Assets_Header (translate("Search"), request);
-  header.setNavigator ();
-  header.addBreadCrumb (menu_logic_search_menu (), menu_logic_search_text ());
+  Assets_Header header = Assets_Header (translate("Search"), webserver_request);
+  header.set_navigator ();
+  header.add_bread_crumb (menu_logic_search_menu (), menu_logic_search_text ());
   page = header.run ();
   
-  Assets_View view;
+  Assets_View view {};
   
   view.set_variable ("bible", bible);
   
-  string script = "var searchBible = \"" + bible + "\";";
-  view.set_variable ("script", script);
+  std::stringstream script {};
+  script << "var searchBible = " << std::quoted(bible) << ";";
+  view.set_variable ("script", script.str());
 
   page += view.render ("search", "strongs");
   
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   
   return page;
 }
