@@ -83,7 +83,7 @@ void sendreceive_sendreceive ([[maybe_unused]] std::string bible)
 
   
   // Synchronize the Bible from the database to the local git repository.
-  filter_git_sync_bible_to_git (webserver_request, bible, directory);
+  filter_git_sync_bible_to_git (bible, directory);
   
 
   // Log the status of the repository: "git status".
