@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,19 +20,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <text/text.h>
 #include <filter/string.h>
 #include <filter/url.h>
-using namespace std;
 
 
 // Class for creating plain text documents.
 
 
-void Text_Text::paragraph (string text)
+void Text_Text::paragraph (std::string text)
 {
   if (thisline != "") {
     // The filter that converts from USFM to clear texts inserts some stuff
     // that's being removed here again, as not desirable in clear text.
-    thisline = filter_string_str_replace (en_space_u2002(), " ", thisline);
-    thisline = filter_string_collapse_whitespace (thisline);
+    thisline = filter::strings::replace (filter::strings::en_space_u2002(), " ", thisline);
+    thisline = filter::strings::collapse_whitespace (thisline);
     output.push_back (thisline);
     thisline = "";
   }
@@ -40,33 +39,33 @@ void Text_Text::paragraph (string text)
 }
 
 
-string Text_Text::line ()
+std::string Text_Text::line ()
 {
   return thisline;
 }
 
 
-void Text_Text::addtext (string text)
+void Text_Text::addtext (std::string text)
 {
   thisline += text;
 }
 
 
-string Text_Text::get ()
+std::string Text_Text::get ()
 {
   paragraph ();
-  return filter_string_implode (output, "\n");
+  return filter::strings::implode (output, "\n");
 }
 
 
-void Text_Text::save (string name)
+void Text_Text::save (std::string name)
 {
   filter_url_file_put_contents (name, get ());
 }
 
 
 // Opens a new clear text note.
-void Text_Text::note (string text)
+void Text_Text::note (std::string text)
 {
   if (!thisnoteline.empty ()) {
     notes.push_back (thisnoteline);
@@ -76,16 +75,14 @@ void Text_Text::note (string text)
 }
 
 
-void Text_Text::addnotetext (string text)
+void Text_Text::addnotetext (std::string text)
 {
   thisnoteline.append (text);
 }
 
 
-string Text_Text::getnote ()
+std::string Text_Text::getnote ()
 {
   note ();
-  return filter_string_implode (notes, "\n");
+  return filter::strings::implode (notes, "\n");
 }
-
-
