@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,5 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 #include <config/libraries.h>
 
-void trash_change_notification (void * webserver_request, int id);
-void trash_consultation_note (void * webserver_request, int id);
+class Webserver_Request;
+
+void trash_change_notification (Webserver_Request& webserver_request, int id);
+void trash_consultation_note (Webserver_Request& webserver_request, int id);
