@@ -27,23 +27,78 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/date.h>
 #pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wswitch-enum"
-#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
-#include <mbedtls/entropy.h>
-#include <mbedtls/ctr_drbg.h>
-#include <mbedtls/certs.h>
-#include <mbedtls/x509.h>
-#include <mbedtls/x509_crt.h>
-#include <mbedtls/ssl.h>
-#include <mbedtls/net_sockets.h>
-#include <mbedtls/error.h>
-#include <mbedtls/ssl_cache.h>
+#pragma clang diagnostic ignored "-Wc99-extensions"
+#pragma clang diagnostic ignored "-Wzero-as-null-pointer-constant"
+#pragma clang diagnostic ignored "-Wold-style-cast"
+#pragma clang diagnostic ignored "-Wswitch-enum"
+#include <mbedtls/version.h>
+#include <mbedtls/platform.h>
+#include "mbedtls/entropy.h"
+#include "mbedtls/ctr_drbg.h"
+#include "mbedtls/x509.h"
+#include "mbedtls/ssl.h"
+#include "mbedtls/net_sockets.h"
+#include "mbedtls/error.h"
+#include "mbedtls/debug.h"
+#include "mbedtls/ssl_cache.h"
 #pragma GCC diagnostic pop
 #ifdef HAVE_WINDOWS
 #include <io.h>
 #endif
 
 
+// Static check on required definitions, taken from the ssl_server.c example.
+#ifndef MBEDTLS_BIGNUM_C
+static_assert (false, "MBEDTLS_BIGNUM_C should be defined");
+#endif
+#ifndef MBEDTLS_PEM_PARSE_C
+static_assert (false, "MBEDTLS_PEM_PARSE_C should be defined");
+#endif
+#ifndef MBEDTLS_ENTROPY_C
+static_assert (false, "MBEDTLS_ENTROPY_C should be defined");
+#endif
+#ifndef MBEDTLS_SSL_TLS_C
+static_assert (false, "MBEDTLS_SSL_TLS_C should be defined");
+#endif
+#ifndef MBEDTLS_SSL_CLI_C
+static_assert (false, "MBEDTLS_SSL_CLI_C should be defined");
+#endif
+#ifndef MBEDTLS_SSL_SRV_C
+static_assert (false, "MBEDTLS_SSL_SRV_C should be defined");
+#endif
+#ifndef MBEDTLS_NET_C
+static_assert (false, "MBEDTLS_NET_C should be defined");
+#endif
+#ifndef MBEDTLS_RSA_C
+static_assert (false, "MBEDTLS_RSA_C should be defined");
+#endif
+#ifndef MBEDTLS_PEM_PARSE_C
+static_assert (false, "MBEDTLS_PEM_PARSE_C should be defined");
+#endif
+#ifndef MBEDTLS_CTR_DRBG_C
+static_assert (false, "MBEDTLS_CTR_DRBG_C should be defined");
+#endif
+#ifndef MBEDTLS_X509_CRT_PARSE_C
+static_assert (false, "MBEDTLS_X509_CRT_PARSE_C should be defined");
+#endif
+#ifndef MBEDTLS_FS_IO
+static_assert (false, "MBEDTLS_FS_IO should be defined");
+#endif
+//#ifndef MBEDTLS_USE_PSA_CRYPTO
+//static_assert (false, "MBEDTLS_USE_PSA_CRYPTO should be defined");
+//#endif
+#ifdef MBEDTLS_X509_REMOVE_INFO
+static_assert (false, "MBEDTLS_X509_REMOVE_INFO should not be defined");
+#endif
+
+
+#if MBEDTLS_VERSION_MAJOR == 2
+#elif MBEDTLS_VERSION_MAJOR == 3
+#else
+static_assert (false, "MbedTLS version other than 2 or 3");
+#endif
+
+
 // Gets a line from a socket.
 // The line may end with a newline, a carriage return, or a CR-LF combination.
 // It terminates the string read with a null character.
@@ -415,7 +470,7 @@ void http_server ()
   WSADATA wsa_data;
   result = WSAStartup(MAKEWORD(2, 2), &wsa_data);
   if (result != 0) {
-    std::string error = "Could not initialize Windows Sockets with error " + filter::strings::convert_to_string (result);
+    std::string error = "Could not initialize Windows Sockets with error " + std::to_string (result);
     std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
@@ -431,7 +486,7 @@ void http_server ()
   // Create a socket for listening for incoming connections.
   SOCKET listen_socket = socket(AF_INET, SOCK_STREAM, 0);
   if (listen_socket == INVALID_SOCKET) {
-    std::string error = "Socket failed with error " + filter::strings::convert_to_string (WSAGetLastError());
+    std::string error = "Socket failed with error " + std::to_string (WSAGetLastError());
     std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
@@ -456,7 +511,7 @@ void http_server ()
   // Listen for multiple connections.
   result = listen(listen_socket, SOMAXCONN);
   if (result == SOCKET_ERROR) {
-    std::string error = "Listen failed with error " + filter::strings::convert_to_string (WSAGetLastError());
+    std::string error = "Listen failed with error " + std::to_string (WSAGetLastError());
     std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
@@ -765,9 +820,10 @@ void https_server ()
 #ifdef RUN_SECURE_SERVER
 
   // The https network port to listen on.
-  // Port 0..9 means this:: Don't run the secure web server.
+  // Port 0..9 means: Don't run the secure web server.
   const std::string network_port = config::logic::https_network_port ();
-  if (network_port.length() <= 1) return;
+  if (network_port.length() <= 1) 
+    return;
   
   // Check whether all the certificates are there and can be read.
   // If not, log some feedback and don't run the secure web server.
@@ -824,10 +880,27 @@ void https_server ()
   mbedtls_ctr_drbg_context ctr_drbg;
   mbedtls_ctr_drbg_init (&ctr_drbg);
 
+#if MBEDTLS_VERSION_MAJOR == 3
+  const psa_status_t psa_status = psa_crypto_init();
+#pragma GCC diagnostic push
+#pragma clang diagnostic ignored "-Wold-style-cast"
+  if (psa_status != PSA_SUCCESS) {
+#pragma GCC diagnostic pop
+    Database_Logs::log("Failure to run PSA crypto initialization: Not running the secure server");
+    return;
+  }
+#endif
+
   // Load the private RSA server key.
   mbedtls_pk_context pkey;
   mbedtls_pk_init (&pkey);
-  int ret = mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr);
+  int ret =
+#if MBEDTLS_VERSION_MAJOR == 2
+  mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr);
+#endif
+#if MBEDTLS_VERSION_MAJOR == 3
+  mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr, mbedtls_ctr_drbg_random, &ctr_drbg);
+#endif
   if (ret != 0) {
     filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
     Database_Logs::log("Invalid " + server_key_path + " so not running secure server");
@@ -928,7 +1001,11 @@ void https_server ()
   mbedtls_ssl_cache_free (&cache);
   mbedtls_ctr_drbg_free (&ctr_drbg);
   mbedtls_entropy_free (&entropy);
+#if MBEDTLS_VERSION_MAJOR == 3
+  mbedtls_psa_crypto_free();
 #endif
+  
+#endif // ifdef RUN_SECURE_SERVER
 }
 
 
